;**************************************************************
;*      
;*	CFU Überblenden
;*  
;*	Einige Überblendungsanimationen
;*  zwischen zwei und mehreren Ebenen
;*	Geschrieben für GIMP 2.6
;*
;*	Einstellbare Parameter:
;*  "Anzahl der Zwischenbilder (Ebenen)"      	Anzahl der Zwischenebenen      
;*  "Zufälliger Übergang"     	                Zufälligen Übergang wählen Ja/Nein      
;*  "Übergang"    	                            Wenn nicht, welcher soll es sein   
;*  "Bewegung modifiziert"			                Soll die Bewegung anders verlaufen			    
;*  "Standzeit Grenzbilder in ms"        	      Standzeit des 1. Bildes in ms      
;*  "Standzeit Zwischenbilder in ms"        	  Standzeit der Zwischenbilder in ms       
;*  "Übergang für alle Ebenen erstellen"      	Soll zwischen jeder Ebene ein Übergang erstellt werden Ja/Nein
;*  "Alle Übergänge gleich"	                    Sollen alle Übergänge gleich sein Ja/Nein (nur wenn zufällige Ü)        
;*  "Schrittgröße (SG) in Pixel" 					      Wert der Schrittgröße
;*  "Bild zuvor Drehen"        			            Bild vor Verarbeitung drehen
;*  "Bild zuvor Horizontal Spiegeln"       	    Bild auch noch horizontal spiegeln
;*  "Bild wieder in Ausgangsposition bringen"   Bid wieder zurückpositionieren
;*      
;*	V1.0 vom "01.03.2012"  
;*
;*                                                
;**************************************************************
                                                  
;**************************************************************
;* Übergang 01ab - Houdini																		
;**************************************************************
(define (sfucf-ueb01-01ab ueLayer ueCounter ueSteps)
	(gimp-layer-set-opacity ueLayer (* ueCounter (/ 100 ueSteps)) )
)

;**************************************************************
;* Übergang 02a - "Falling Down" 
;**************************************************************
(define (sfucf-ueb01-02a ueLayer ueCounter ueSteps ueKGV ueImage)
	(let* ( (k 0)
					(layerMask 0)
				)
		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)
		(gimp-selection-all ueImage)
		(gimp-selection-shrink ueImage (* ueCounter (/ ueKGV ueSteps)))
		(gimp-selection-invert ueImage)
		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 02b - Von Innen
;**************************************************************
(define (sfucf-ueb01-02b ueLayer ueCounter ueSteps ueKGV ueImage)
	(let* ( (k 0)
					(layerMask 0)
				)
		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)
		(gimp-selection-all ueImage)
		(gimp-selection-shrink ueImage (* (- ueSteps ueCounter) (/ ueKGV ueSteps)))
		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 03ab - "Blind Side"  																		
;**************************************************************
(define (sfucf-ueb01-03ab ueLayer ueCounter ueSteps ueBreit ueHoch ueImage ueSG)
	(let* ( (k 0)
          (stH (* ueCounter (/ (+ ueSteps ueSG) ueSteps)))
					(layerMask 0)
				)

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)
		(while (< k ueHoch)
			(begin
				(gimp-rect-select ueImage 0 k ueBreit stH CHANNEL-OP-ADD FALSE 0)		
				(set! k (+ k (+ ueSG ueSteps)))	
			)		
		)
		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 04a - "Squaredance"
;**************************************************************
(define (sfucf-ueb01-04a ueLayer ueCounter ueSteps ueBreit ueHoch ueImage ueSG)
	(let* ( (k 0)
					(l 0)
					(sX 0)
					(sY 0)
          (stP (* (+ ueSteps (- ueSG 1)) 2))
          (stH (* ueCounter (/ (+ ueSteps (- ueSG 1)) ueSteps) 2))
					(layerMask 0)
				)

		(set! sX (/ (modulo (- ueBreit 1) stP)2))
		(set! sY (/ (modulo (- ueHoch  1) stP)2))

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)
		(set! k sY)
		(while (< k ueHoch)
			(begin
				(set! l sX)
					(while (< l ueBreit)
						(begin
							(gimp-rect-select ueImage 
									(- l (/ stH 2))
									(- k (/ stH 2)) 
									stH  
									stH 
									CHANNEL-OP-ADD FALSE 0)	
							(set! l (+ l stP))	
						)
					)					
				(set! k (+ k stP))	
			)		
		)
		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 04b - "Squaredance" 																		
;**************************************************************
(define (sfucf-ueb01-04b ueLayer ueCounter ueSteps ueBreit ueHoch ueImage ueSG)
	(let* ( (k 0)
					(l 0)
					(sX 0)
					(sY 0)
          (stP (* (+ ueSteps (- ueSG 1)) 2))
          (stH (* (- ueSteps ueCounter) (/ (+ ueSteps (- ueSG 1)) ueSteps) 2))
					(layerMask 0)
				)

		(set! sX (/ (modulo (- ueBreit 1) stP)2))
		(set! sY (/ (modulo (- ueHoch  1) stP)2))

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)
		(set! k sY)
		(while (< k ueHoch)
			(begin
				(set! l sX)
					(while (< l ueBreit)
						(begin
							(gimp-rect-select ueImage 
									(- l (/ stH 2))
									(- k (/ stH 2)) 
									stH  
									stH 
									CHANNEL-OP-ADD FALSE 0)	
							(set! l (+ l stP))	
						)
					)					
				(set! k (+ k stP))	
			)		
		)
		(gimp-selection-invert ueImage)
		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 05ab - "Circledance" 
;**************************************************************
(define (sfucf-ueb01-05ab ueLayer ueCounter ueSteps ueBreit ueHoch ueImage ueSG)
	(let* ( (k 0)
					(l 0)
					(sX 0)
					(sY 0)
					(layerMask 0)
				)

		(set! sX (/ (modulo (- ueBreit 1) (* ueSG ueSteps 2))2))
		(set! sY (/ (modulo (- ueHoch  1) (* ueSG ueSteps 2))2))

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)
		(set! k sY)
		(while (< k ueHoch)
			(begin
				(set! l sX)
					(while (< l ueBreit)
						(begin
							(gimp-ellipse-select ueImage 
									(- l (* ueSG ueCounter))
									(- k (* ueSG ueCounter)) 
									(* ueSG ueCounter 2) 
									(* ueSG ueCounter 2) 
									CHANNEL-OP-ADD TRUE FALSE 0)	
							(set! l (+ l (* ueSG ueSteps )))	
						)
					)					
				(set! k (+ k (* ueSG ueSteps )))	
			)		
		)
		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 05b - "Circledance"
;**************************************************************
(define (sfucf-ueb01-05b ueLayer ueCounter ueSteps ueBreit ueHoch ueImage ueSG)
	(let* ( (k 0)
					(l 0)
					(sX 0)
					(sY 0)
					(layerMask 0)
				)

		(set! sX (/ (modulo (- ueBreit 1) (* ueSG ueSteps 2))2))
		(set! sY (/ (modulo (- ueHoch  1) (* ueSG ueSteps 2))2))

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)
		(set! k sY)
		(while (< k ueHoch)
			(begin
				(set! l sX)
					(while (< l ueBreit)
						(begin
							(gimp-ellipse-select ueImage 
									(- l (* ueSG (- ueSteps ueCounter)))
									(- k (* ueSG (- ueSteps ueCounter))) 
									(* ueSG (- ueSteps ueCounter) 2) 
									(* ueSG (- ueSteps ueCounter) 2) 
									CHANNEL-OP-ADD TRUE FALSE 0)	
							(set! l (+ l (* ueSG ueSteps )))	
						)
					)					
				(set! k (+ k (* ueSG ueSteps )))	
			)		
		)
    
		(gimp-selection-invert ueImage)
    (gimp-edit-fill layerMask WHITE-FILL)
    (gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)


;**************************************************************
;* Übergang 06a - "Hide-And-Seek"
;**************************************************************
(define (sfucf-ueb01-06a ueLayer ueCounter ueSteps ueBreit ueHoch ueImage ueGGV)
	(let* ( (kH (* ueCounter (/ ueHoch ueSteps)))
					(layerMask 0)
					(vect '())
				)

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)

	  (set! vect '())
  	(set! vect (append vect (list 0 0)))
  	(set! vect (append vect (list ueBreit 0)))
  	(set! vect (append vect (list ueBreit kH)))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

	  (set! vect '())
  	(set! vect (append vect (list ueBreit ueHoch)))
  	(set! vect (append vect (list 0 ueHoch)))
  	(set! vect (append vect (list 0 (- ueHoch kH))))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)



		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)
;**************************************************************
;* Übergang 06b - "Hide-And-Seek"
;**************************************************************
(define (sfucf-ueb01-06b ueLayer ueCounter ueSteps ueBreit ueHoch ueImage ueGGV)
	(let* ( (kH (* (- ueSteps ueCounter) (/ ueHoch ueSteps)))
					(layerMask 0)
					(vect '())
				)

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)

	  (set! vect '())
  	(set! vect (append vect (list 0 0)))
  	(set! vect (append vect (list ueBreit 0)))
  	(set! vect (append vect (list ueBreit kH)))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

	  (set! vect '())
  	(set! vect (append vect (list ueBreit ueHoch)))
  	(set! vect (append vect (list 0 ueHoch)))
  	(set! vect (append vect (list 0 (- ueHoch kH))))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)


		(gimp-selection-invert ueImage)
		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 07a "Stargate"
;**************************************************************
(define (sfucf-ueb01-07a ueLayer ueCounter ueSteps ueBreit ueHoch ueImage ueGGV)
	(let* ( (kH (* ueCounter (/ ueHoch ueSteps)))
					(layerMask 0)
					(vect '())
				)

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)

	  (set! vect '())
  	(set! vect (append vect (list 0 0)))
  	(set! vect (append vect (list ueBreit 0)))
  	(set! vect (append vect (list ueBreit kH)))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

	  (set! vect '())
  	(set! vect (append vect (list ueBreit ueHoch)))
  	(set! vect (append vect (list 0 ueHoch)))
  	(set! vect (append vect (list 0 (- ueHoch kH))))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

	  (set! vect '())
  	(set! vect (append vect (list 0 0)))
  	(set! vect (append vect (list ueBreit 0)))
  	(set! vect (append vect (list 0 kH)))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

	  (set! vect '())
  	(set! vect (append vect (list ueBreit ueHoch)))
  	(set! vect (append vect (list 0 ueHoch)))
  	(set! vect (append vect (list ueBreit (- ueHoch kH))))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)


		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 07b - "Stargate" 																		
;**************************************************************
(define (sfucf-ueb01-07b ueLayer ueCounter ueSteps ueBreit ueHoch ueImage ueGGV)
	(let* ( (kH (* (- ueSteps ueCounter) (/ ueHoch ueSteps)))
					(layerMask 0)
					(vect '())
				)

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)

	  (set! vect '())
  	(set! vect (append vect (list 0 0)))
  	(set! vect (append vect (list ueBreit 0)))
  	(set! vect (append vect (list ueBreit kH)))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

	  (set! vect '())
  	(set! vect (append vect (list ueBreit ueHoch)))
  	(set! vect (append vect (list 0 ueHoch)))
  	(set! vect (append vect (list 0 (- ueHoch kH))))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

	  (set! vect '())
  	(set! vect (append vect (list 0 0)))
  	(set! vect (append vect (list ueBreit 0)))
  	(set! vect (append vect (list 0 kH)))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

	  (set! vect '())
  	(set! vect (append vect (list ueBreit ueHoch)))
  	(set! vect (append vect (list 0 ueHoch)))
  	(set! vect (append vect (list ueBreit (- ueHoch kH))))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

		(gimp-selection-invert ueImage)
		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 08a - "Crossroad"
;**************************************************************
(define (sfucf-ueb01-08a ueLayer ueCounter ueSteps ueBreit ueHoch ueImage ueGGV)
	(let* ( (kB (* ueCounter (/ (/ ueBreit ueSteps)2)))
					(kH (* ueCounter (/ (/ ueHoch  ueSteps)2)))
					(layerMask 0)
				)

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)

		(gimp-rect-select ueImage 0 0 kB kH CHANNEL-OP-ADD FALSE 0)		
		(gimp-rect-select ueImage 0 (- ueHoch kH) kB kH CHANNEL-OP-ADD FALSE 0)		
		(gimp-rect-select ueImage (- ueBreit kB) 0 kB kH CHANNEL-OP-ADD FALSE 0)		
		(gimp-rect-select ueImage (- ueBreit kB) (- ueHoch kH) kB kH CHANNEL-OP-ADD FALSE 0)		

		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 8b - "Crossroad"                                    
;**************************************************************
(define (sfucf-ueb01-08b ueLayer ueCounter ueSteps ueBreit ueHoch ueImage ueGGV)
	(let* ( (kB (* (- ueSteps ueCounter) (/ (/ ueBreit ueSteps)2)))
					(kH (* (- ueSteps ueCounter) (/ (/ ueHoch  ueSteps)2)))
					(layerMask 0)
				)

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)

		(gimp-rect-select ueImage 0 0 kB kH CHANNEL-OP-ADD FALSE 0)		
		(gimp-rect-select ueImage 0 (- ueHoch kH) kB kH CHANNEL-OP-ADD FALSE 0)		
		(gimp-rect-select ueImage (- ueBreit kB) 0 kB kH CHANNEL-OP-ADD FALSE 0)		
		(gimp-rect-select ueImage (- ueBreit kB) (- ueHoch kH) kB kH CHANNEL-OP-ADD FALSE 0)		

		(gimp-selection-invert ueImage)
		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)


;**************************************************************
;* Übergang 9ab - "Rush Hour"                                    
;**************************************************************
(define (sfucf-ueb01-09ab ueLayer ueCounter ueSteps ueBreit ueHoch ueImage ueSG)
	(let* ( (i 0)
          (kB (*  ueCounter (/ ueBreit ueSteps)))
					(kH (/ ueHoch ueSG))
          (layerMask 0)
        )

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)
    
    (while (< i ueSG)
      (begin
        (if (= (modulo i 2) 0)
          (gimp-rect-select ueImage 0              (- ueHoch (* kH (- ueSG i)))  kB (+ kH 1) CHANNEL-OP-ADD FALSE 0)		
          (gimp-rect-select ueImage (- ueBreit kB) (- ueHoch (* kH (- ueSG i)))  kB (+ kH 1) CHANNEL-OP-ADD FALSE 0)		
        )      
        (set! i (+ i 1))
      )
    )

		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
  )
)

;**************************************************************
;* Übergang 10a - "Stardust"
;**************************************************************
(define (sfucf-ueb01-10a ueLayer ueCounter ueSteps ueBreit ueHoch ueImage)
	(let* ( (i 0)
          (layerMask 0)
          (pLinks (/ ueBreit 4))
          (pBreit (* pLinks 2))
          (pOben (/ ueHoch 4))
          (pHoch (* pOben 2))
          (kB (*  ueCounter (/ (/ ueBreit 4) ueSteps))) ; Breitenverschiebung
					(kH (*  ueCounter (/ (/ ueHoch 4)  ueSteps))) ; Höhenverschiebung
        )

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)
    
    (gimp-rect-select ueImage (- pLinks kB) (- pOben kH) (+ pBreit (* kB 2)) (+ pHoch (* kH 2)) CHANNEL-OP-ADD FALSE 0)		
    (gimp-rect-select ueImage (+ pLinks kB) (+ pOben kH) (- pBreit (* kB 2)) (- pHoch (* kH 2)) CHANNEL-OP-SUBTRACT FALSE 0)		

		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
  )
)

;**************************************************************
;* Übergang 10b - "Stardust"                                    
;**************************************************************
(define (sfucf-ueb01-10b ueLayer ueCounter ueSteps ueBreit ueHoch ueImage)
	(let* ( (i 0)
          (layerMask 0)
          (pLinks (/ ueBreit 4))
          (pBreit (* pLinks 2))
          (pOben (/ ueHoch 4))
          (pHoch (* pOben 2))
          (kB (*  (- ueSteps ueCounter) (/ (/ ueBreit 4) ueSteps))) ; Breitenverschiebung
					(kH (*  (- ueSteps ueCounter) (/ (/ ueHoch 4)  ueSteps))) ; Höhenverschiebung
        )

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)
    
    (gimp-rect-select ueImage (- pLinks kB) (- pOben kH) (+ pBreit (* kB 2)) (+ pHoch (* kH 2)) CHANNEL-OP-ADD FALSE 0)		
    (gimp-rect-select ueImage (+ pLinks kB) (+ pOben kH) (- pBreit (* kB 2)) (- pHoch (* kH 2)) CHANNEL-OP-SUBTRACT FALSE 0)		

		(gimp-selection-invert ueImage)
		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
  )
)

;**************************************************************
;* Übergang 11a - "Magneto"
;**************************************************************
(define (sfucf-ueb01-11a ueLayer ueCounter ueSteps ueBreit ueHoch ueImage)
	(let* ( (i 0)
          (layerMask 0)
          (pHoch (+ (/ ueHoch 2) 1))
          (pBreit (+ (/ ueBreit 2) 1))
          (kB (*  ueCounter (/ (/ ueBreit 2) ueSteps))) ; Breitenverschiebung
					(kH (*  ueCounter (/ (/ ueHoch 2)  ueSteps))) ; Höhenverschiebung
        )

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)
    
    (gimp-rect-select ueImage 0                  0                kB     pHoch CHANNEL-OP-ADD FALSE 0)		
    (gimp-rect-select ueImage (- ueBreit pBreit) 0                pBreit kH    CHANNEL-OP-ADD FALSE 0)		
    (gimp-rect-select ueImage (- ueBreit kB)     (- ueHoch pHoch) kB     pHoch CHANNEL-OP-ADD FALSE 0)		
    (gimp-rect-select ueImage 0                  (- ueHoch kH)    pBreit kH    CHANNEL-OP-ADD FALSE 0)		
    

		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
  )
)

;**************************************************************
;* Übergang 11b - "Magneto"                                    
;**************************************************************
(define (sfucf-ueb01-11b ueLayer ueCounter ueSteps ueBreit ueHoch ueImage)
	(let* ( (i 0)
          (layerMask 0)
          (pHoch (+ (/ ueHoch 2) 1))
          (pBreit (+ (/ ueBreit 2) 1))
          (kB (*  (- ueSteps ueCounter) (/ (/ ueBreit 2) ueSteps))) ; Breitenverschiebung
					(kH (*  (- ueSteps ueCounter) (/ (/ ueHoch 2)  ueSteps))) ; Höhenverschiebung
        )

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)
    
    (gimp-rect-select ueImage 0                  0                kB     pHoch CHANNEL-OP-ADD FALSE 0)		
    (gimp-rect-select ueImage (- ueBreit pBreit) 0                pBreit kH    CHANNEL-OP-ADD FALSE 0)		
    (gimp-rect-select ueImage (- ueBreit kB)     (- ueHoch pHoch) kB     pHoch CHANNEL-OP-ADD FALSE 0)		
    (gimp-rect-select ueImage 0                  (- ueHoch kH)    pBreit kH    CHANNEL-OP-ADD FALSE 0)		
    
		(gimp-selection-invert ueImage)
		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
  )
)

;**************************************************************
;* Übergang 12a - "Mailbox"
;**************************************************************
(define (sfucf-ueb01-12a ueLayer ueCounter ueSteps ueBreit ueHoch ueImage)
	(let* ( (beginn (* (/ ueBreit 8) 3))
          (kH (* ueCounter (/ ueHoch ueSteps)))
          (kB1 (/ (* (- ueHoch kH) beginn) ueHoch))
          (kB2 (- ueBreit kB1))
					(layerMask 0)
					(vect '())
				)

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)

	  (set! vect '())
  	(set! vect (append vect (list 0 0)))
  	(set! vect (append vect (list ueBreit 0)))
  	(set! vect (append vect (list kB2 kH)))
  	(set! vect (append vect (list kB1 kH)))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 12b - "Mailbox"                                    
;**************************************************************
(define (sfucf-ueb01-12b ueLayer ueCounter ueSteps ueBreit ueHoch ueImage)
	(let* ( (beginn (* (/ ueBreit 8) 3))
          (kH (* ( - ueSteps ueCounter) (/ ueHoch ueSteps)))
          (kB1 (/ (* (- ueHoch kH) beginn) ueHoch))
          (kB2 (- ueBreit kB1))
					(layerMask 0)
					(vect '())
				)

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)

	  (set! vect '())
  	(set! vect (append vect (list 0 0)))
  	(set! vect (append vect (list ueBreit 0)))
  	(set! vect (append vect (list kB2 kH)))
  	(set! vect (append vect (list kB1 kH)))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

		(gimp-selection-invert ueImage)
		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 13a - "Cut"
;**************************************************************
(define (sfucf-ueb01-13a ueLayer ueCounter ueSteps ueBreit ueHoch ueImage)
	(let* ( (i 0)
          (layerMask 0)
					(kH (*  ueCounter (/ (/ ueHoch 2)  ueSteps))) ; Höhenverschiebung          
          (kU (- ueHoch kH))
        )

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)
    
    (gimp-rect-select ueImage 0  0  ueBreit kH CHANNEL-OP-ADD FALSE 0)		
    (gimp-rect-select ueImage 0 kU  ueBreit kH CHANNEL-OP-ADD FALSE 0)		

		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
  )
)

;**************************************************************
;* Übergang 13b - "Cut" 																		
;**************************************************************
(define (sfucf-ueb01-13b ueLayer ueCounter ueSteps ueBreit ueHoch ueImage)
	(let* ( (i 0)
          (layerMask 0)
					(kH (* ( - ueSteps ueCounter) (/ (/ ueHoch 2)  ueSteps))) ; Höhenverschiebung          
          (kU (- ueHoch kH))
        )

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)
    
    (gimp-rect-select ueImage 0  0  ueBreit kH CHANNEL-OP-ADD FALSE 0)		
    (gimp-rect-select ueImage 0 kU  ueBreit kH CHANNEL-OP-ADD FALSE 0)		

		(gimp-selection-invert ueImage)
		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
  )
)

;**************************************************************
;* Übergang 14a - "Chess"
;**************************************************************
(define (sfucf-ueb01-14a ueLayer ueCounter ueSteps ueBreit ueHoch ueImage ueSG)
	(let* ( (k 0)
					(l 0)
					(v -1)
					(sX 0)
					(sY 0)
					(sZ 0)
					(layerMask 0)
				)

		(set! sZ (* ueSG ueSteps 2))
		(set! sX (- (/ (modulo (- ueBreit 1) (* ueSG ueSteps 4))2) (* sZ 2)))
		(set! sY (- (/ (modulo ueHoch (* ueSG ueSteps 2))2) sZ))

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)
		(set! k sY)
		(while (< k ueHoch)
			(begin
				(set! v (* v -1))
				(set! l sX)
					(if (= v -1)
						(set! l (- l sZ))
					)
					(while (< l ueBreit)
						(begin
							(gimp-rect-select ueImage 
									l
									k
									(* ueSG ueCounter 4) 
;									(* ueSG ueCounter 2) 
									(* sZ)
									CHANNEL-OP-ADD FALSE 0)	
							(set! l (+ l (* ueSG ueSteps 4)))	
						)
					)					
				(set! k (+ k sZ))	
			)		
		)
		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 14b - "Chess" 																		
;**************************************************************
(define (sfucf-ueb01-14b ueLayer ueCounter ueSteps ueBreit ueHoch ueImage ueSG)
	(let* ( (k 0)
					(l 0)
					(v -1)
					(sX 0)
					(sY 0)
					(stZ (+ ueSteps (- ueSG 1)))
          (stP (* stZ 2))
          (stB (* ueCounter (/ stP ueSteps)))
					(layerMask 0)
				)

		(set! sX (- (/ (modulo (- ueBreit 1) stP) 2) stP))
		(set! sY (- (/ (modulo ueHoch        stZ) 2) stZ))

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)
		(set! k sY)
		(while (< k ueHoch)
			(begin
				(set! v (* v -1))
				(set! l sX)
					(if (= v -1)
						(set! l (- l stZ))
					)
					(while (< l ueBreit)
						(begin
							(gimp-rect-select ueImage 
									l
									k
									stB 
									stZ
									CHANNEL-OP-ADD FALSE 0)	
							(set! l (+ l stP))	
						)
					)					
				(set! k (+ k stZ))	
			)		
		)
		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 15a - "Crusader"
;**************************************************************
(define (sfucf-ueb01-15a ueLayer ueCounter ueSteps ueBreit ueHoch ueImage)
	(let* ( (dB (* ueCounter (/ ueBreit ueSteps)) )
          (kB1 (/ (- ueBreit dB) 2))
          (kB2 (- ueBreit kB1))
          (dH (* ueCounter (/ ueHoch ueSteps)) )
          (kH1 (/ (- ueHoch dH) 2))
          (kH2 (- ueHoch kH1))
          (layerMask 0)
					(vect '())
				)

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)

	  (set! vect '())
  	(set! vect (append vect (list kB1 0)))
  	(set! vect (append vect (list kB2 0)))
  	(set! vect (append vect (list kB1 ueHoch)))
  	(set! vect (append vect (list kB2 ueHoch)))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)
       
    (set! vect '())
  	(set! vect (append vect (list 0 kH1)))
  	(set! vect (append vect (list 0 kH2)))
  	(set! vect (append vect (list ueBreit kH1)))
  	(set! vect (append vect (list ueBreit kH2)))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 15b - "Crusader" 																		
;**************************************************************
(define (sfucf-ueb01-15b ueLayer ueCounter ueSteps ueBreit ueHoch ueImage)
	(let* ( (dB (* (- ueSteps ueCounter) (/ ueBreit ueSteps)) )
          (kB1 (/ (- ueBreit dB) 2))
          (kB2 (- ueBreit kB1))
          (dH (* (- ueSteps ueCounter) (/ ueHoch ueSteps)) )
          (kH1 (/ (- ueHoch dH) 2))
          (kH2 (- ueHoch kH1))
          (layerMask 0)
					(vect '())
				)

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)

	  (set! vect '())
  	(set! vect (append vect (list kB1 0)))
  	(set! vect (append vect (list kB2 0)))
  	(set! vect (append vect (list kB1 ueHoch)))
  	(set! vect (append vect (list kB2 ueHoch)))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)
       
    (set! vect '())
  	(set! vect (append vect (list 0 kH1)))
  	(set! vect (append vect (list 0 kH2)))
  	(set! vect (append vect (list ueBreit kH1)))
  	(set! vect (append vect (list ueBreit kH2)))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

 		(gimp-selection-invert ueImage)
		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 16a - "Twister"
;**************************************************************
(define (sfucf-ueb01-16a ueLayer ueCounter ueSteps ueBreit ueHoch ueImage)
	(let* ( (kB1 (* ueCounter (/ ueBreit ueSteps)) )
          (kB2 (- ueBreit kB1))
          (kH1 (* ueCounter (/ ueHoch ueSteps)) )
          (kH2 (- ueHoch kH1))
          (layerMask 0)
					(vect '())
				)

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)

	  (set! vect '())
  	(set! vect (append vect (list 0 0)))
  	(set! vect (append vect (list kB1 0)))
  	(set! vect (append vect (list kB2 ueHoch)))
  	(set! vect (append vect (list ueBreit ueHoch)))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)
       
    (set! vect '())
  	(set! vect (append vect (list ueBreit 0)))
  	(set! vect (append vect (list ueBreit kH1)))
  	(set! vect (append vect (list 0 kH2)))
  	(set! vect (append vect (list 0 ueHoch)))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 16b - "Twister" 																		
;**************************************************************
(define (sfucf-ueb01-16b ueLayer ueCounter ueSteps ueBreit ueHoch ueImage)
	(let* ( (kB1 (* (- ueSteps ueCounter) (/ ueBreit ueSteps)) )
          (kB2 (- ueBreit kB1))
          (kH1 (* (- ueSteps ueCounter) (/ ueHoch ueSteps)) )
          (kH2 (- ueHoch kH1))
          (layerMask 0)
					(vect '())
				)

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)

	  (set! vect '())
  	(set! vect (append vect (list 0 0)))
  	(set! vect (append vect (list kB1 0)))
  	(set! vect (append vect (list kB2 ueHoch)))
  	(set! vect (append vect (list ueBreit ueHoch)))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)
       
    (set! vect '())
  	(set! vect (append vect (list ueBreit 0)))
  	(set! vect (append vect (list ueBreit kH1)))
  	(set! vect (append vect (list 0 kH2)))
  	(set! vect (append vect (list 0 ueHoch)))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

 		(gimp-selection-invert ueImage)
		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)


;**************************************************************
;* Übergang 17a - "Packman" 																		
;**************************************************************
(define (sfucf-ueb01-17a ueLayer ueCounter ueSteps ueBreit ueHoch ueImage)
	(let* ( (kB1 (* ueCounter (/ ueBreit ueSteps)) )
          (kH1 (* ueCounter (/ ueHoch ueSteps)) )
          (layerMask 0)
					(vect '())
				)

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)

	  (set! vect '())
  	(set! vect (append vect (list 0 0)))
  	(set! vect (append vect (list ueBreit 0)))
  	(set! vect (append vect (list ueBreit kH1)))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)
       
    (set! vect '())
  	(set! vect (append vect (list 0 0)))
  	(set! vect (append vect (list 0 ueHoch)))
  	(set! vect (append vect (list kB1 ueHoch)))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 17b - "Packman" 																		
;**************************************************************
(define (sfucf-ueb01-17b ueLayer ueCounter ueSteps ueBreit ueHoch ueImage)
	(let* ( (kB1 (* (- ueSteps ueCounter) (/ ueBreit ueSteps)) )
          (kH1 (* (- ueSteps ueCounter) (/ ueHoch ueSteps)) )
          (layerMask 0)
					(vect '())
				)

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)

	  (set! vect '())
  	(set! vect (append vect (list 0 0)))
  	(set! vect (append vect (list ueBreit 0)))
  	(set! vect (append vect (list ueBreit kH1)))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)
       
    (set! vect '())
  	(set! vect (append vect (list 0 0)))
  	(set! vect (append vect (list 0 ueHoch)))
  	(set! vect (append vect (list kB1 ueHoch)))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

 		(gimp-selection-invert ueImage)
		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 18a - "Halftime" 																		
;**************************************************************
(define (sfucf-ueb01-18a ueLayer ueCounter ueSteps ueBreit ueHoch ueImage)
	(let* ( (lang (/ (+ ueBreit ueHoch) ueSteps))
          (stH1 (/ ueHoch lang))
          (stB2 (- ueSteps stH1))
          (kB (* (- ueCounter stH1) (/ ueBreit stB2)) )
          (kH (* ueCounter (/ ueHoch  stH1)) )
					(layerMask 0)
					(vect '())
				)

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)

	  (set! vect '())
  	(set! vect (append vect (list ueBreit 0)))
    (if (> ueCounter stH1)
      (set! vect (append vect (list ueBreit ueHoch)))
      (set! vect (append vect (list ueBreit kH)))
    )
    (if (> ueCounter stH1)
      (set! vect (append vect (list 0 0)))
      (set! vect (append vect (list 0 (- ueHoch kH))))
    )
  	(set! vect (append vect (list 0 ueHoch)))
    
		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)
        
    (if (> ueCounter stH1)
      (begin
      
	  (set! vect '())
  	(set! vect (append vect (list ueBreit ueHoch)))
  	(set! vect (append vect (list (- ueBreit kB) ueHoch)))
   	(set! vect (append vect (list kB 0)))
  	(set! vect (append vect (list 0 0)))
      )    
    )
		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 18b - "Halftime" 																		
;**************************************************************
(define (sfucf-ueb01-18b ueLayer ueCounter ueSteps ueBreit ueHoch ueImage)
	(let* ( (lang (/ (+ ueBreit ueHoch) ueSteps))
          (stHB (/ ueBreit 2))
          (stB0 (/ stHB lang))
          (stH1 (/ ueHoch lang))
          (stB2 (- ueSteps stH1 stB0))
          
          (kB0 (* ueCounter (/ stHB  stB0)) )
          (kH1 (* (- ueCounter stB0) (/ ueHoch  stH1)) )
          (kB2 (* (- ueCounter stB0 stH1) (/ stHB stB2)) )
					(layerMask 0)
					(vect '())
				)

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)

    
 	  (set! vect '())
  	(set! vect (append vect (list stHB 0)))
    (if (> ueCounter stB0)
      (set! vect (append vect (list ueBreit 0)))
      (set! vect (append vect (list (+ stHB kB0) 0)))
    )    
    (if (> ueCounter stB0)
      (set! vect (append vect (list 0 ueHoch)))
      (set! vect (append vect (list (- stHB kB0) ueHoch)))
    )
    (set! vect (append vect (list stHB ueHoch)))
    
		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

    (if (> ueCounter stB0)
      (begin
    
	  (set! vect '())
  	(set! vect (append vect (list ueBreit 0)))
    (if (> ueCounter (+ stB0 stH1))
      (set! vect (append vect (list ueBreit ueHoch)))
      (set! vect (append vect (list ueBreit kH1)))
    )
    (if (> ueCounter (+ stB0 stH1))
      (set! vect (append vect (list 0 0)))
      (set! vect (append vect (list 0 (- ueHoch kH1))))
    )
  	(set! vect (append vect (list 0 ueHoch)))
    
		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)
        
      )
    )
       
       
    (if (> ueCounter (+ stB0 stH1))
      (begin
      
	  (set! vect '())
  	(set! vect (append vect (list ueBreit ueHoch)))
  	(set! vect (append vect (list (- ueBreit kB2) ueHoch)))
   	(set! vect (append vect (list kB2 0)))
  	(set! vect (append vect (list 0 0)))
      )    
    )
		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 19a - "Fulltime"                                    
;**************************************************************
(define (sfucf-ueb01-19a ueLayer ueCounter ueSteps ueBreit ueHoch ueImage)
	(let* ( (lang (/ (* (+ ueBreit ueHoch) 2) ueSteps))
          (stH1 (/ ueHoch lang))
          (stB1 (/ (- ueSteps stH1 stH1) 2))
          (kB  (* (- ueCounter stH1) (/ ueBreit stB1)) )
          (kH  (* ueCounter (/ ueHoch  stH1)) )
          (kH2 (* (- ueCounter stH1 stB1) (/ ueHoch  stH1)) )
          (kB2 (* (- ueCounter stH1 stB1 stH1) (/ ueBreit stB1)) )
          (mB (/ ueBreit 2))
          (mH (/ ueHoch 2))
					(layerMask 0)
					(vect '())
				)

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)

	  (set! vect '())
  	(set! vect (append vect (list ueBreit 0)))
    (if (> ueCounter stH1)
      (set! vect (append vect (list ueBreit ueHoch)))
      (set! vect (append vect (list ueBreit kH)))
    )
  	(set! vect (append vect (list mB mH)))
    
		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)
        
    (if (> ueCounter stH1)
      (begin
      
        (set! vect '())
        (set! vect (append vect (list ueBreit ueHoch)))
        (if (> ueCounter (+ stH1 stB1))
          (set! vect (append vect (list 0 ueHoch)))
          (set! vect (append vect (list (- ueBreit kB) ueHoch)))
        )
        (set! vect (append vect (list mB mH)))
              
        (gimp-free-select ueImage (length vect) 
            (list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)
      )
    )

    (if (> ueCounter (+ stH1 stB1))
      (begin
      
        (set! vect '())
        (set! vect (append vect (list 0 ueHoch)))
        (if (> ueCounter (+ stH1 stH1 stB1))
          (set! vect (append vect (list 0 0)))
          (set! vect (append vect (list 0 (- ueHoch kH2))))
        )
        (set! vect (append vect (list mB mH)))
              
        (gimp-free-select ueImage (length vect) 
            (list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)
      )
    )
    
    (if (> ueCounter (+ stH1 stB1 stH1))
      (begin
        (set! vect '())
        (set! vect (append vect (list 0 0)))
        (set! vect (append vect (list kB2 0)))
        (set! vect (append vect (list mB mH)))
              
        (gimp-free-select ueImage (length vect) 
            (list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)
      )
    )

		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 19b - "Fulltime"                                    
;**************************************************************
(define (sfucf-ueb01-19b ueLayer ueCounter ueSteps ueBreit ueHoch ueImage)
	(let* ( (lang (/ (* (+ ueBreit ueHoch) 2) ueSteps))
          (stHH (/ ueHoch 2))
          (stHB (/ ueBreit 2))
          (stB0 (/ stHB lang))
          (stH1 (/ ueHoch lang))
          (stB2 (- ueSteps stH1 stH1 stB0 stB0))
          
          (kB0 (* ueCounter (/ stHB stB0)) )
          (kH1 (* (- ueCounter stB0) (/ ueHoch  stH1)) )
          (kB2 (* (- ueCounter stB0 stH1) (/ ueBreit stB2)) )
          (kH3 (* (- ueCounter stB0 stH1 stB2) (/ ueHoch  stH1)) )
          (kB4 (* (- ueCounter stB0 stH1 stB2 stH1) (/ stHB stB0)) )
          
;          (mB (/ ueBreit 2))
;          (mH (/ ueHoch 2))
          
					(layerMask 0)
					(vect '())
				)

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)

	  (set! vect '())
  	(set! vect (append vect (list stHB 0)))
    (if (> ueCounter stB0)
      (set! vect (append vect (list ueBreit 0)))
      (set! vect (append vect (list (+ stHB kB0) 0)))
    )
  	(set! vect (append vect (list stHB stHH)))
    
		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

        
    (if (> ueCounter stB0)
      (begin
      
        (set! vect '())
        (set! vect (append vect (list ueBreit 0)))
        (if (> ueCounter stB0 stH1)
          (set! vect (append vect (list ueBreit ueHoch)))
          (set! vect (append vect (list ueBreit kH1)))
        )
        (set! vect (append vect (list stHB stHH)))
        
        (gimp-free-select ueImage (length vect) 
            (list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)
      )
    )   
        
        
    (if (> ueCounter (+ stB0 stH1))
      (begin
      
        (set! vect '())
        (set! vect (append vect (list ueBreit ueHoch)))
        (if (> ueCounter (+ stB0 stH1 stB2))
          (set! vect (append vect (list 0 ueHoch)))
          (set! vect (append vect (list (- ueBreit kB2) ueHoch)))
        )
        (set! vect (append vect (list stHB stHH)))
              
        (gimp-free-select ueImage (length vect) 
            (list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)
      )
    )

    
    (if (> ueCounter (+ stB0 stH1 stB2))
      (begin
      
        (set! vect '())
        (set! vect (append vect (list 0 ueHoch)))
        (if (> ueCounter (+ stB0 stH1 stH1 stB2))
          (set! vect (append vect (list 0 0)))
          (set! vect (append vect (list 0 (- ueHoch kH3))))
        )
        (set! vect (append vect (list stHB stHH)))
              
        (gimp-free-select ueImage (length vect) 
            (list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)
      )
    )
    
    (if (> ueCounter (+ stB0 stH1 stB2 stH1))
      (begin
        (set! vect '())
        (set! vect (append vect (list 0 0)))
        (set! vect (append vect (list kB4 0)))
        (set! vect (append vect (list stHB stHH)))
              
        (gimp-free-select ueImage (length vect) 
            (list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)
      )
    )

		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 20a - "On Stage"
;**************************************************************
(define (sfucf-ueb01-20a ueLayer ueCounter ueSteps ueBreit ueHoch ueImage)
	(let* ( (kB (* ueCounter (/ ueBreit ueSteps)) )
          (kH (* ueCounter (/ ueHoch ueSteps)) )
					(layerMask 0)
					(vect '())
				)

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)

	  (set! vect '())
  	(set! vect (append vect (list 0 0)))
  	(set! vect (append vect (list kB 0)))
  	(set! vect (append vect (list ueBreit (- ueHoch kH))))
  	(set! vect (append vect (list ueBreit ueHoch)))
  	(set! vect (append vect (list (- ueBreit kB) ueHoch)))
  	(set! vect (append vect (list 0 kH)))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 20b - "On Stage"                                    
;**************************************************************
(define (sfucf-ueb01-20b ueLayer ueCounter ueSteps ueBreit ueHoch ueImage)
	(let* ( (kB (* (- ueSteps ueCounter) (/ ueBreit ueSteps)) )
          (kH (* (- ueSteps ueCounter) (/ ueHoch ueSteps)) )
					(layerMask 0)
					(vect '())
				)

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)

	  (set! vect '())
  	(set! vect (append vect (list 0 0)))
  	(set! vect (append vect (list kB 0)))
  	(set! vect (append vect (list ueBreit (- ueHoch kH))))
  	(set! vect (append vect (list ueBreit ueHoch)))
  	(set! vect (append vect (list (- ueBreit kB) ueHoch)))
  	(set! vect (append vect (list 0 kH)))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

 		(gimp-selection-invert ueImage)
		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 21a - "Surprise
;**************************************************************
(define (sfucf-ueb01-21a ueLayer ueCounter ueSteps ueBreit ueHoch ueImage)
	(let* ( (kB (* ueCounter (/ (/ ueBreit 2) ueSteps)) )
          (kH (* ueCounter (/ (/ ueHoch  2) ueSteps)) )
					(layerMask 0)
					(vect '())
				)

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)

	  (set! vect '())
  	(set! vect (append vect (list 0 0)))
  	(set! vect (append vect (list kB 0)))
  	(set! vect (append vect (list ueBreit (- ueHoch kH))))
  	(set! vect (append vect (list ueBreit ueHoch)))
  	(set! vect (append vect (list (- ueBreit kB) ueHoch)))
  	(set! vect (append vect (list 0 kH)))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

	  (set! vect '())
  	(set! vect (append vect (list (- ueBreit kB) 0)))
  	(set! vect (append vect (list ueBreit 0)))
  	(set! vect (append vect (list ueBreit kH)))
  	(set! vect (append vect (list kB ueHoch)))
  	(set! vect (append vect (list 0 ueHoch)))
  	(set! vect (append vect (list 0 (- ueHoch kH))))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang 21b - "Surprise
;**************************************************************
(define (sfucf-ueb01-21b ueLayer ueCounter ueSteps ueBreit ueHoch ueImage)
	(let* ( (kB (* (- ueSteps ueCounter) (/ (/ ueBreit 2) ueSteps)) )
          (kH (* (- ueSteps ueCounter) (/ (/ ueHoch  2) ueSteps)) )
					(layerMask 0)
					(vect '())
				)

		(set! layerMask (car (gimp-layer-create-mask ueLayer ADD-BLACK-MASK)))
		(gimp-layer-add-mask ueLayer layerMask)

	  (set! vect '())
  	(set! vect (append vect (list 0 0)))
  	(set! vect (append vect (list kB 0)))
  	(set! vect (append vect (list ueBreit (- ueHoch kH))))
  	(set! vect (append vect (list ueBreit ueHoch)))
  	(set! vect (append vect (list (- ueBreit kB) ueHoch)))
  	(set! vect (append vect (list 0 kH)))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

	  (set! vect '())
  	(set! vect (append vect (list (- ueBreit kB) 0)))
  	(set! vect (append vect (list ueBreit 0)))
  	(set! vect (append vect (list ueBreit kH)))
  	(set! vect (append vect (list kB ueHoch)))
  	(set! vect (append vect (list 0 ueHoch)))
  	(set! vect (append vect (list 0 (- ueHoch kH))))

		(gimp-free-select ueImage (length vect) 
				(list-to-array vect) CHANNEL-OP-ADD FALSE FALSE 0)

 		(gimp-selection-invert ueImage)
		(gimp-edit-fill layerMask WHITE-FILL)
		(gimp-selection-none ueImage)
		(gimp-layer-remove-mask ueLayer MASK-APPLY)
	)
)

;**************************************************************
;* Übergang xx - Noch offen
;**************************************************************
(define (sfucf-ueb01-xx ueLayer ueCounter ueSteps)
	(let* ((i 0))
		(gimp-layer-set-opacity ueLayer (* ueCounter (/ 100 ueSteps)) )
	)
)






;**************************************************************
;* Namensvergabe
;**************************************************************
(define (sfucf-set-name ueLayer frameNum ueSpeed ueMod)
	(let* (
			(layerName (car (gimp-drawable-get-name ueLayer)))
		)
    (set! layerName (string-append "Bild " (number->string frameNum) " (" (number->string ueSpeed) "ms)" " (replace)"))
	  (gimp-drawable-set-name ueLayer layerName)     
	)
)

;**************************************************************
;* Erzeugt ein Array aus einer Liste
;**************************************************************
(define (list-to-array contents)
  (let* (	(alen (length contents))
    			(n_array (cons-array alen 'double))
    			(count 0))    		
 	(for-each	(lambda (val)
            (aset n_array count val)
            (set! count (+ count 1)))
						contents)
   n_array))
    
;------------------------------------------------------------------------------


;**************************************************************
;* Hauptprogramm
;**************************************************************
(define (script-fu-cf-animationen-uebergaenge-01 
						inBild 
						inEbene 
						inSteps 
						inZufall
						inAuswahl
            inUmkehr
						inMs1	
						inMs2
						inAlles
						inAllesGleich								; Alle Übergänge gleich
						inSG												; Schrittgröße
            inDrehen
            inSpiegeln
            inOrgPos
				)

	(let* (	
    (outBild (car (gimp-image-duplicate inBild)))                    		
 		(layers (gimp-image-get-layers outBild))
 		(num-layers (car layers))
 		(layer-array (cadr layers))
 		(i num-layers)
 		(j i)
 		(ugAnz 21)                      ; Anzahl der Methoden
    (ugSG inSG)
 		(ugSel inAuswahl)
    (pUmkehr inUmkehr)
    (pDrehen inDrehen)
    (pSpiegeln inSpiegeln)
		(counter-layer num-layers)
		(counter-steps 0)
		(counterBilder 1)
 		(orgLayer  (car (gimp-image-get-active-layer outBild)))
 		(actLayer  0)
 		(orgLayera 0)
 		(orgLayerb 0)
 		(newLayera 0)
 		(newLayerb 0)
 		(actDraw 0)
		(imageWidth  (car (gimp-image-width outBild)))
		(imageHeight  (car (gimp-image-height outBild)))
		(imageKGV (/ imageHeight 2))
		(imageGGV (/ imageHeight 2))
		(imageDRT (/ imageHeight 3))
		(imageVRT (/ imageHeight 4))

 	      )

    
(if (> i 1)
	(begin
  
; Auswahl aufheben
	(gimp-selection-none outBild)	


;(gimp-message (number->string (random 2)))	
	(if (= inZufall TRUE)
    (begin
      (set! ugSel (random ugAnz)) 
      (set! ugSG  (+ (random 10) 1))
      (set! pUmkehr (modulo (random 100) 2))
      (set! pDrehen (modulo (random 100) 2))
      (set! pSpiegeln (modulo (random 100) 2))
    )
  )
 
 
; Löschen der Bildnamen 
; Anwenden der Ebenenmaske
; Ebenensichtbarkeit einschalten	      
(while (> i 0)
	(begin 	  	    
 	  (set! i (- i 1))    
		(set! orgLayera (vector-ref layer-array i))		
	  (gimp-drawable-set-name orgLayera "CFU")     
	)
)


(set! i num-layers)

(while (> i 0)
	(begin 	  
  
    (if (and (= inZufall TRUE) (= inAllesGleich FALSE))
      (begin
        (set! ugSel (random ugAnz)) 
        (set! ugSG  (+ (random 10) 1))
        (set! pUmkehr (modulo (random 100) 2))
        (set! pDrehen (modulo (random 100) 2))
        (set! pSpiegeln (modulo (random 100) 2))
     )
    )
    
 
; Soll das Bild gedreht werden
    (cond ((= pDrehen 1)
                (gimp-image-rotate outBild ROTATE-90))
          ((= pDrehen 2)
                (gimp-image-rotate outBild ROTATE-180))
          ((= pDrehen 3)
                (gimp-image-rotate outBild ROTATE-270))
    )


; Soll das Bild Horizontal gespiegelt werden
    (if (= pSpiegeln TRUE)
      (gimp-image-flip outBild ORIENTATION-HORIZONTAL)
    )
    
 
    (set! orgLayer  (car (gimp-image-get-active-layer outBild)))
    (set! imageWidth  (car (gimp-image-width outBild)))
    (set! imageHeight  (car (gimp-image-height outBild)))
    (set! imageKGV (/ imageHeight 2))
    (set! imageGGV (/ imageHeight 2))
    (set! imageDRT (/ imageHeight 3))
    (set! imageVRT (/ imageHeight 4))

    (if (> imageKGV (/ imageWidth 2))
      (set! imageKGV (/ imageWidth 2)))
    (if (< imageGGV (/ imageWidth 2))
      (set! imageGGV (/ imageWidth 2)))


 	  (set! i (- i 1))    
    (set! j (- i 1))
    (if (= i 0)
    	(set! j (- num-layers 1))
    )
    
		(sfucf-set-name (vector-ref layer-array i) counterBilder inMs1 "replace")
		(set! counterBilder (+ counterBilder 1))    
    
		(if (or (= inAlles TRUE) (= orgLayer (vector-ref layer-array i)))
		 (begin

		(set! orgLayera (car(gimp-layer-new-from-drawable (vector-ref layer-array i) outBild)))		
		(set! orgLayerb (car(gimp-layer-new-from-drawable (vector-ref layer-array j) outBild)))
		(gimp-image-set-active-layer outBild (vector-ref layer-array i))
		
		(set! counter-steps 0)
		(set! actLayer orgLayera)

 
  	(while (< counter-steps inSteps) 
    	(begin 
   
				(set! newLayera (car(gimp-layer-new-from-drawable orgLayera outBild)))
				(set! newLayerb (car(gimp-layer-new-from-drawable orgLayerb outBild)))
 
 				(gimp-image-add-layer outBild newLayera -1)               
 				(gimp-image-add-layer outBild newLayerb -1)               
 
				(set! actLayer (car (gimp-image-get-active-layer outBild)))
				
	 	(if (= pUmkehr FALSE)
      (begin
        (cond ((= ugSel 0)
          	(sfucf-ueb01-01ab actLayer (+ counter-steps 1) (+ inSteps 1)))
          ((= ugSel 1)
            (sfucf-ueb01-02a actLayer (+ counter-steps 1) (+ inSteps 1) imageKGV outBild))
          ((= ugSel 2)
            (sfucf-ueb01-03ab actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild ugSG))
          ((= ugSel 3)
            (sfucf-ueb01-04a actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild ugSG))
          ((= ugSel 4)
            (sfucf-ueb01-05ab actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild ugSG))
          ((= ugSel 5)
            (sfucf-ueb01-06a actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild imageGGV))
          ((= ugSel 6)
            (sfucf-ueb01-07a actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild imageGGV))
          ((= ugSel 7)
            (sfucf-ueb01-08a actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild imageGGV))
          ((= ugSel 8)
            (sfucf-ueb01-09ab actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild ugSG))
          ((= ugSel 9)
            (sfucf-ueb01-10a actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild))
          ((= ugSel 10)
            (sfucf-ueb01-11a actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild))
          ((= ugSel 11)
            (sfucf-ueb01-12a  actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild))
          ((= ugSel 12)
            (sfucf-ueb01-13a  actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild))
          ((= ugSel 13)
            (sfucf-ueb01-14a  actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild ugSG))
          ((= ugSel 14)
            (sfucf-ueb01-15a  actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild))
          ((= ugSel 15)
            (sfucf-ueb01-16a  actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild))
          ((= ugSel 16)
            (sfucf-ueb01-17a  actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild))
          ((= ugSel 17)
            (sfucf-ueb01-18a  actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild))
          ((= ugSel 18)
            (sfucf-ueb01-19a  actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild))
          ((= ugSel 19)
            (sfucf-ueb01-20a  actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild))
          ((= ugSel 20)
            (sfucf-ueb01-21a  actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild))
        )
      )
      (begin                            ; else
        (cond ((= ugSel 0)
          	(sfucf-ueb01-01ab actLayer (+ counter-steps 1) (+ inSteps 1)))
          ((= ugSel 1)
            (sfucf-ueb01-02b actLayer (+ counter-steps 1) (+ inSteps 1) imageKGV outBild))
          ((= ugSel 2)
            (sfucf-ueb01-03ab actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild ugSG))
          ((= ugSel 3)
            (sfucf-ueb01-04b actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild ugSG))
          ((= ugSel 4)
            (sfucf-ueb01-05ab actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild ugSG))
          ((= ugSel 5)
            (sfucf-ueb01-06b actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild imageGGV))
          ((= ugSel 6)
            (sfucf-ueb01-07b actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild imageGGV))
          ((= ugSel 7)
            (sfucf-ueb01-08b actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild imageGGV))
          ((= ugSel 8)
            (sfucf-ueb01-09ab actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild ugSG))
          ((= ugSel 9)
            (sfucf-ueb01-10b actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild))
          ((= ugSel 10)
            (sfucf-ueb01-11b actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild))
          ((= ugSel 11)
            (sfucf-ueb01-12b  actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild))
          ((= ugSel 12)
            (sfucf-ueb01-13b  actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild))
          ((= ugSel 13)
            (sfucf-ueb01-14b  actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild ugSG))
          ((= ugSel 14)
            (sfucf-ueb01-15b  actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild))
          ((= ugSel 15)
            (sfucf-ueb01-16b  actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild))
          ((= ugSel 16)
            (sfucf-ueb01-17b  actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild))
          ((= ugSel 17)
            (sfucf-ueb01-18b  actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild))
          ((= ugSel 18)
            (sfucf-ueb01-19b  actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild))          
          ((= ugSel 19)
            (sfucf-ueb01-20b  actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild))          
          ((= ugSel 20)
            (sfucf-ueb01-21b  actLayer (+ counter-steps 1) (+ inSteps 1) imageWidth imageHeight outBild))          
          
        )
      )
    )


			
; (sfucf-ueb01-01 actLayer (+ counter-steps 1) (+ inSteps 1))		

			
				(set! actLayer (gimp-image-merge-down outBild actLayer EXPAND-AS-NECESSARY))
				(set! actDraw (car (gimp-image-get-active-drawable outBild)))
				(sfucf-set-name actDraw counterBilder inMs2 "replace")
				(set! counterBilder (+ counterBilder 1))    

				
				(set! counter-steps (+ counter-steps 1))    
			);begin
 		);while
))


; Bild-Ausgangsposition wieder herstellen
    (if (= inOrgPos TRUE)
      (begin
        (if (= pSpiegeln TRUE)
          (gimp-image-flip outBild ORIENTATION-HORIZONTAL)
        )
        
        (cond ((= pDrehen 1)
                    (gimp-image-rotate outBild ROTATE-270))
              ((= pDrehen 2)
                    (gimp-image-rotate outBild ROTATE-180))
              ((= pDrehen 3)
                    (gimp-image-rotate outBild ROTATE-90))
        )
      )
    )


	);begin
);while



(gimp-image-set-active-layer outBild (vector-ref layer-array (- num-layers 1)))
 
 
 		(gimp-display-new outBild)
		(gimp-displays-flush)

	)
	(gimp-message "Es werden mindestens 2 Ebenen benötigt!")
)



 	);let
) ;;def

 
	(script-fu-register
		"script-fu-cf-animationen-uebergaenge-01"       ;Name der Funktion, die aufgerufen werden soll
		"CFU Überblenden"                               ;Name des Skripts
		"Überblendung von einer Ebene auf eine Andere"  ;Beschreibung des Skripts
		"CF"                                     	      ;Name des Autors
		"Copyleft by CF"                         	      ;Copyright-Infos
		"01.03.2012"                             	      ;Datum
		"RGB* GRAY* INDEXED*"                     
		SF-IMAGE "Das Bild" 0
		SF-DRAWABLE "Die Ebene" 0
 		SF-ADJUSTMENT "Anzahl der Zwischenbilder (Ebenen)"     			'(19 1 500 1 10 0 0)
		SF-TOGGLE     "Zufälliger Übergang" FALSE
 		SF-OPTION 		"Übergang"     '(	"Houdini" 
 																		"Falling Down" 
 																		"Blind Side (SG)" 
 																		"Squaredance (SG)"
 																		"Circledance (SG)" 
 																		"Hide-And-Seek"
 																		"Stargate"
 																		"Crossroad"
                                    "Rush Hour (SG)"
                                    "Stardust"
                                    "Magneto"
                                    "Mailbox"
                                    "Cut"
 																		"Chess (SG)"
 																		"Crusader"
 																		"Twister"
 																		"Packman"
 																		"Halftime"
 																		"Fulltime"
                                    "On Stage"
                                    "Surprise"
 																		)
		SF-TOGGLE     "Bewegung modifiziert" FALSE
 		SF-ADJUSTMENT "Standzeit Grenzbilder in ms"    			'(2000 1 9999 1 10 0 0)
 		SF-ADJUSTMENT "Standzeit Zwischenbilder in ms"   	'(40 1 9999 1 10 0 0)
		SF-TOGGLE     "Übergang für alle Ebenen erstellen" TRUE
		SF-TOGGLE     "Alle Übergänge gleich" FALSE
 		SF-ADJUSTMENT "Schrittgröße (SG) in Pixel"   	'(1 1 999 1 10 0 0)
 		SF-OPTION 		"Bild zuvor Drehen"  '(	"Nicht Drehen" 
                                          "um 90 Grad" 
                                          "um 180 Grad" 
                                          "um 270 Grad" 
                                      )
		SF-TOGGLE     "Bild zuvor Horizontal Spiegeln" FALSE
		SF-TOGGLE     "Bild wieder in Ausgangsposition bringen" TRUE
	)

	(script-fu-menu-register "script-fu-cf-animationen-uebergaenge-01" "<Image>/CFU/Animationen")		
